@@ -1021,7 +1021,7 @@ class RecordingHandle:
                  monitoring_intervals,
                  do_profile,
                  kdamonds, add_child_tasks, record_mem_footprint,
-                 record_vmas, timeout):
+                 record_vmas, record_proc_stats, timeout):
         self.tracepoint = tracepoint
         self.file_path = file_path
         self.file_format = file_format
@@ -1037,7 +1037,8 @@ class RecordingHandle:
         if record_vmas is True:
             self.vmas_snapshots = []
 
-        self.proc_stats = []
+        if record_proc_stats is True:
+            self.proc_stats = []
 
         self.timeout = timeout
 
@@ -1072,7 +1073,9 @@ def start_recording(handle):
         if handle.vmas_snapshots is not None:
             record_proc_vmas(handle.kdamonds, handle.vmas_snapshots)
 
-        record_proc_stats(handle.kdamonds, handle.proc_stats)
+        if handle.proc_stats is not None:
+            record_proc_stats(handle.kdamonds, handle.proc_stats)
+
         if (handle.timeout is not None and
             time.time() - start_time >= handle.timeout):
             break
@@ -1131,8 +1134,9 @@ def finish_recording(handle):
     if handle.vmas_snapshots is not None:
         save_proc_vmas(handle.vmas_snapshots, '%s.vmas' % handle.file_path,
                        handle.file_permission)
-    save_proc_stats(handle.proc_stats, '%s.proc_stats' % handle.file_path,
-                    handle.file_permission)
+    if handle.proc_stats is not None:
+        save_proc_stats(handle.proc_stats, '%s.proc_stats' % handle.file_path,
+                        handle.file_permission)
 
 # for snapshot
 
@@ -1184,7 +1188,8 @@ def tried_regions_to_snapshot(scheme, intervals, merge_regions):
                     last_region.nr_accesses == tried_region.nr_accesses and
                     last_region.age == tried_region.age):
                 last_region.end = tried_region.end
-                last_region.sz_filter_passed += tried_region.sz_filter_passed
+                if last_region.sz_filter_passed is not None:
+                    last_region.sz_filter_passed += tried_region.sz_filter_passed
                 continue
         regions.append(tried_region)
     if scheme.tried_bytes is not None:
@@ -1455,21 +1460,21 @@ def get_snapshot_records_of(request):
     get records containing single snapshot from running kdamonds
     '''
     if request.tried_regions_of is None:
+        access_pattern = _damon.DamosAccessPattern()
         filters = []
         if request.record_filter:
+            access_pattern = request.record_filter.access_pattern
+
             addr_ranges = request.record_filter.address_ranges
             if addr_ranges and _damon.feature_supported('schemes_filters_addr'):
                 for start, end in addr_ranges:
                     filters.append(_damon.DamosFilter(
                         'addr', False,
                         address_range=_damon.DamonRegion(start, end)))
-            if request.record_filter.damos_filters is not None:
-                filters += request.record_filter.damos_filters
-            monitor_scheme = _damon.Damos(
-                    access_pattern=request.record_filter.access_pattern,
-                    filters=filters)
-        else:
-            monitor_scheme = _damon.Damos()
+        if request.snapshot_damos_filters is not None:
+            filters += request.snapshot_damos_filters
+        monitor_scheme = _damon.Damos(
+                access_pattern=access_pattern, filters=filters)
 
         records, err = get_snapshot_records(monitor_scheme,
                 request.total_sz_only, not request.dont_merge_regions)
@@ -1487,11 +1492,10 @@ class RecordFilter:
     snapshot_index_ranges = None
     temperature_ranges = None
     temperature_weights = None
-    damos_filters = None
 
     def __init__(self, access_pattern, address_ranges, snapshot_sz_ranges,
                  snapshot_time_ranges, snapshot_index_ranges,
-                 temperature_ranges, temperature_weights, damos_filters):
+                 temperature_ranges, temperature_weights):
         self.access_pattern = access_pattern
         self.address_ranges = address_ranges
         self.snapshot_sz_ranges = snapshot_sz_ranges
@@ -1499,7 +1503,6 @@ class RecordFilter:
         self.snapshot_index_ranges = snapshot_index_ranges
         self.temperature_ranges = temperature_ranges
         self.temperature_weights = temperature_weights
-        self.damos_filters = damos_filters
 
     def to_kvpairs(self, raw):
         kvpairs = {'access_pattern': self.access_pattern.to_kvpairs(raw)}
@@ -1523,7 +1526,6 @@ class RecordFilter:
         kvpairs['snapshot_index_ranges'] = self.snapshot_index_ranges
         kvpairs['temperature_ranges'] = self.temperature_ranges
         kvpairs['temperature_weights'] = self.temperature_weights
-        kvpairs['damos_filters'] = [f.to_kvpairs() for f in self.damos_filters]
         return kvpairs
 
     def filter_records(self, records):
@@ -1543,6 +1545,15 @@ class RecordFilter:
             filter_records_by_temperature(records, self.temperature_ranges,
                                           self.temperature_weights)
 
+def set_snapshot_damos_filters_option(parser):
+    parser.add_argument(
+            '--snapshot_damos_filter', nargs='+', action='append', default=[],
+            metavar='<damos filter argument>',
+            help=' '.join([
+                'Region-internal DAMOS filters for the snapshot.',
+                'Format is same to --damos_filter.'
+                ]))
+
 class RecordGetRequest:
     # TODO: Extend to be used for recording
 
@@ -1550,6 +1561,8 @@ class RecordGetRequest:
     tried_regions_of = None
     record_file = None
 
+    snapshot_damos_filters = None
+
     record_filter = None
 
     # more detailed requests
@@ -1557,19 +1570,23 @@ class RecordGetRequest:
     dont_merge_regions = None
 
     def __init__(
-            self, tried_regions_of=None, record_file=None, record_filter=None,
+            self, tried_regions_of=None, record_file=None,
+            snapshot_damos_filters=None,
+            record_filter=None,
             total_sz_only=False, dont_merge_regions=True):
         self.tried_regions_of = tried_regions_of
         self.record_file = record_file
+        self.snapshot_damos_filters = snapshot_damos_filters
         self.record_filter = record_filter
         self.total_sz_only = total_sz_only
         self.dont_merge_regions = dont_merge_regions
 
-def get_records(tried_regions_of=None, record_file=None, record_filter=None,
+def get_records(tried_regions_of=None, record_file=None,
+                snapshot_damos_filters=None, record_filter=None,
                 total_sz_only=False, dont_merge_regions=True):
     request = RecordGetRequest(
-            tried_regions_of, record_file, record_filter,
-            total_sz_only, dont_merge_regions)
+            tried_regions_of, record_file, snapshot_damos_filters,
+            record_filter, total_sz_only, dont_merge_regions)
 
     # If record is live snapshot, access pattern filtering is applied with
     # get_snapshot_records_of() because it uses DAMOS to get the snapshot.  If
@@ -1581,8 +1598,7 @@ def get_records(tried_regions_of=None, record_file=None, record_filter=None,
     if record_filter:
         filter_copy = copy.deepcopy(record_filter)
     else:
-        filter_copy = RecordFilter(None, None, None, None, None, None, None,
-                                   None)
+        filter_copy = RecordFilter(None, None, None, None, None, None, None)
 
     if request.record_file is None:
         records, err = get_snapshot_records_of(request)
@@ -1659,34 +1675,28 @@ def args_to_filter(args):
         # ignore size
         temperature_weights = [0, 100, 100]
 
-    damos_filters, err = _damon_args.damos_options_to_filters(
-            args.damos_filter)
-    if err is not None:
-        return None, 'wrong --damos_filter (%s)' % err
-
     return RecordFilter(access_pattern, addr_range,
                         snapshot_sz_ranges, snapshot_time,
                         snapshot_index_ranges,
-                        args.temperature, temperature_weights,
-                        damos_filters), None
+                        args.temperature, temperature_weights), None
 
 def set_filter_argparser(parser):
     parser.add_argument('--sz_region', metavar=('<min>', '<max>'), nargs=2,
             default=['min', 'max'],
-            help='min/max size of regions (bytes) to show')
+            help='min/max size of regions (bytes) to filter in')
     parser.add_argument('--access_rate', metavar=('<min>', '<max>'), nargs=2,
             default=['min', 'max'],
-            help='min/max access rate of regions (percent) to show')
+            help='min/max access rate of regions (percent) to filter in')
     parser.add_argument('--age', metavar=('<min>', '<max>'), nargs=2,
             default=['min', 'max'],
-            help='min/max age of regions (seconds) to show')
+            help='min/max age of regions (seconds) to filter in')
     parser.add_argument('--address', metavar=('<start>', '<end>'), nargs=2,
             action='append',
-            help='address ranges to show')
+            help='address ranges to filter in')
     parser.add_argument(
             '--sz_snapshot', metavar=('<min>', '<max>'), nargs=2,
             action='append',
-            help='min/max total size of regions of snapshots to show')
+            help='min/max total size of regions of snapshots to filter in')
     parser.add_argument(
             '--snapshot_time', metavar=('<start (ns)>', '<end (ns)>'), nargs=2,
             action='append',
@@ -1698,8 +1708,4 @@ def set_filter_argparser(parser):
     parser.add_argument(
             '--temperature', metavar=('<min>', '<max>'), nargs=2, type=int,
             action='append',
-            help='min/max temperature of regions to show')
-    parser.add_argument(
-            '--damos_filter', nargs='+', action='append', default=[],
-            metavar='<filter argument>',
-            help='damos filter (type, matching, and optional arguments)')
+            help='min/max temperature of regions to filter in')
