@@ -629,32 +629,46 @@ class DamosWatermarks:
 class DamosFilter:
     filter_type = None  # anon, memcg, young, addr, or target
     matching = None
+    filter_pass = None
     memcg_path = None
     address_range = None    # DamonRegion
     damon_target_idx = None
     scheme = None
 
-    def __init__(self, filter_type, matching, memcg_path=None,
-            address_range=None, damon_target_idx=None):
+    def __init__(self, filter_type, matching, filter_pass=False,
+                 memcg_path=None, address_range=None, damon_target_idx=None):
         self.filter_type = filter_type
         self.matching = _damo_fmt_str.text_to_bool(matching)
         self.memcg_path = memcg_path
+        self.filter_pass = _damo_fmt_str.text_to_bool(filter_pass)
         self.address_range = address_range
         if damon_target_idx != None:
             self.damon_target_idx = _damo_fmt_str.text_to_nr(damon_target_idx)
 
     def to_str(self, raw):
-        txt = '%s %s' % (self.filter_type,
-                'matching' if self.matching else 'nomatching')
+        type_to_text = {
+                'anon': ['anon pages', 'file-backed pages'],
+                'memcg': ['pages in memcg', 'pages not in memcg'],
+                'young': ['young pages', 'old pages'],
+                'addr': ['memory in addr', 'memory not in addr'],
+                'target': ['memory in target', 'memory not in target']
+                }
+        words = []
+        if self.filter_pass:
+            words.append('pass')
+        else:
+            words.append('block')
+        match_idx = 0 if self.matching is True else 1
+        words.append(type_to_text[self.filter_type][match_idx])
         if self.filter_type in ['anon', 'young']:
-            return txt
+            return ' '.join(words)
         if self.filter_type == 'memcg':
-            return '%s %s' % (txt, self.memcg_path)
+            return ' '.join(words + [self.memcg_path])
         if self.filter_type == 'addr':
-            return '%s %s' % (txt, self.address_range.to_str(raw))
+            return ' '.join(words + [self.address_range.to_str(raw)])
         if self.filter_type == 'target':
-            return '%s %s' % (txt, _damo_fmt_str.format_nr(
-                    self.damon_target_idx, raw))
+            return ' '.join(words + [_damo_fmt_str.format_nr(
+                    self.damon_target_idx, raw)])
 
     def __str__(self):
         return self.to_str(False)
@@ -664,7 +678,9 @@ class DamosFilter:
 
     @classmethod
     def from_kvpairs(cls, kv):
-        return DamosFilter(kv['filter_type'], kv['matching'],
+        return DamosFilter(
+                kv['filter_type'], kv['matching'],
+                kv['filter_pass'] if 'filter_pass' in kv else False,
                 kv['memcg_path'] if kv['filter_type'] == 'memcg' else '',
                 DamonRegion.from_kvpairs(kv['address_range'])
                     if kv['filter_type'] == 'addr' else None,
@@ -675,6 +691,7 @@ class DamosFilter:
         return collections.OrderedDict([
             ('filter_type', self.filter_type),
             ('matching', self.matching),
+            ('filter_pass', self.filter_pass),
             ('memcg_path', self.memcg_path),
             ('address_range', self.address_range.to_kvpairs(raw) if
                 self.address_range != None else None),
@@ -682,6 +699,10 @@ class DamosFilter:
                 _damo_fmt_str.format_nr(self.damon_target_idx, raw)
                 if self.damon_target_idx != None else None)])
 
+    def handled_by_ops(self):
+        # whether this filter is handled by DAMON operations set layer
+        return self.filter_type in ['anon', 'memcg', 'young']
+
 class DamosStats:
     nr_tried = None
     sz_tried = None
@@ -1076,6 +1097,7 @@ features = ['record',       # was in DAMON patchset, but not merged in mainline
             'schemes_filters_young',    # merged in v6.10-rc1
             'schemes_migrate',          # merged in v6.11-rc1
             'sz_ops_filter_passed',     # developing
+            'pass_filter',              # developing
             ]
 
 _damon_fs = None
