@@ -96,6 +96,37 @@ def schemes_option_to_damos(schemes):
     except Exception as json_err:
         return None, '%s' % json_err
 
+def handle_err_get_filter_pass(filter_type, optional_args):
+    '''
+    optional_args are for filter target memory type specification, and whether
+    the filter is pass filter or block filter.
+    Target memory type specification options depend on the type.
+    Whether to pass or block is optional (block by default)
+    '''
+    type_to_nr_type_args = {
+            'anon': 0,
+            'memcg': 1,
+            'young': 0,
+            'addr': 2,
+            'target': 1}
+    if not filter_type in type_to_nr_type_args:
+        return None, 'unsupported filter target type'
+    nr_type_args = type_to_nr_type_args[filter_type]
+    len_args = len(optional_args)
+    if len_args < nr_type_args:
+        return None, '<%d filter optional args (%s)' % (
+                nr_rype_args, optional_args)
+    elif len_args > nr_type_args + 1:
+        return None, '>%d filter optional args (%s)' % (
+                nr_type_args + 1, optional_args)
+
+    if len_args == nr_type_args:
+        return False, None
+    filter_pass_keyword = optional_args[-1]
+    if not filter_pass_keyword in ['pass', 'block']:
+        return None, 'wrong filter_pass keyword (%s)' % filter_pass_keyword
+    return filter_pass_keyword == 'pass', None
+
 def damos_options_to_filters(filters_args):
     filters = []
     if filters_args == None:
@@ -110,21 +141,21 @@ def damos_options_to_filters(filters_args):
         if not fmatching in ['matching', 'nomatching']:
             return None, 'unsupported matching keyword (%s)' % fmatching
         fmatching = fmatching == 'matching'
+        filter_pass, err = handle_err_get_filter_pass(ftype, fargs)
+        if err is not None:
+            return None, 'filter arguments handling failed (%s)' % fargs
+
         if ftype == 'anon':
-            if len(fargs):
-                return (None, 'anon filter receives no arguments but (%s)'
-                        % fargs)
-            filters.append(_damon.DamosFilter(ftype, fmatching))
+            filters.append(_damon.DamosFilter(
+                ftype, fmatching, filter_pass=filter_pass))
         elif ftype == 'memcg':
-            if len(fargs) != 1:
-                return None, 'wrong number of memcg arguments (%s)' % fargs
             memcg_path = fargs[0]
-            filters.append(_damon.DamosFilter(ftype, fmatching, memcg_path))
+            filters.append(_damon.DamosFilter(
+                ftype, fmatching, memcg_path=memcg_path,
+                filter_pass=filter_pass))
         elif ftype == 'young':
-            if len(fargs):
-                return (None,
-                        'young filter receives no arguments but (%s)' % fargs)
-            filters.append(_damon.DamosFilter(ftype, fmatching))
+            filters.append(_damon.DamosFilter(
+                ftype, fmatching, filter_pass=filter_pass))
         elif ftype == 'addr':
             if len(fargs) != 2:
                 return None, 'wrong number of addr arguments (%s)' % fargs
@@ -133,14 +164,17 @@ def damos_options_to_filters(filters_args):
             except Exception as e:
                 return None, 'wrong addr range (%s, %s)' % (fargs, e)
             filters.append(
-                    _damon.DamosFilter(ftype, fmatching, None, addr_range))
+                    _damon.DamosFilter(
+                        ftype, fmatching, filter_pass=filter_pass,
+                        address_range=addr_range))
         elif ftype == 'target':
             if len(fargs) != 1:
                 return None, 'wrong number of target argument (%s)' % fargs
             try:
                 filters.append(
-                        _damon.DamosFilter(ftype, fmatching, None, None,
-                            fargs[0]))
+                        _damon.DamosFilter(
+                            ftype, fmatching, filter_pass=filter_pass,
+                            damon_target_idx=fargs[0]))
             except Exception as e:
                 return None, 'target filter creation failed (%s, %s)' % (
                         fargs[0], e)
@@ -148,31 +182,6 @@ def damos_options_to_filters(filters_args):
             return None, 'unsupported filter type'
     return filters, None
 
-def passed_bytes_type_str(damos_filter_args):
-    filters, err = damos_options_to_filters(damos_filter_args)
-    if err is not None:
-        return None, err
-    type_tokens = []
-    for filter in filters:
-        if filter.filter_type == 'anon':
-            if filter.matching is True:
-                type_tokens.append('file-backed')
-            else:
-                type_tokens.append('anon')
-        elif filter.filter_type == 'memcg':
-            if filter.matching is True:
-                type_tokens.append('not belong to %s' % filter.memcg_path)
-            else:
-                type_tokens.append('belong to %s' % filter.memcg_path)
-        elif filter.filter_type == 'young':
-            if filter.matching is True:
-                type_tokens.append('old')
-            else:
-                type_tokens.append('young')
-    if len(type_tokens) == 0:
-        return 'no filter', None
-    return ' and '.join(type_tokens), None
-
 def damos_quotas_cons_arg(cmd_args):
     time_ms = 0
     sz_bytes = 0
