@@ -99,6 +99,13 @@ def write_filter_dir(dir_path, filter_):
         # addr/target are merged in 6.6-rc1
         return err
 
+    if (not os.path.isfile(os.path.join(dir_path, 'pass')) and
+        filter_.filter_pass is True):
+        return 'kernel is not supporting pass_filter'
+    else:
+        err = _damo_fs.write_file(os.path.join(dir_path, 'pass'),
+                                  'Y' if filter_.filter_pass else 'N')
+
     if filter_.memcg_path is not None:
         err = _damo_fs.write_file(
                 os.path.join(dir_path, 'memcg_path'), filter_.memcg_path)
@@ -537,15 +544,17 @@ def files_content_to_watermarks(files_content):
             int(files_content['low']))
 
 def files_content_to_damos_filters(files_content):
-    return [_damon.DamosFilter(filter_kv['type'].strip(),
-            filter_kv['matching'].strip(),
-            filter_kv['memcg_path'].strip(),
-            _damon.DamonRegion(filter_kv['addr_start'].strip(),
-                filter_kv['addr_end'].strip())
-                if 'addr_start' in filter_kv and 'addr_end' in filter_kv
-                else None,
-            filter_kv['damon_target_idx']
-                if 'damon_target_idx' in filter_kv else None)
+    return [_damon.DamosFilter(
+        filter_kv['type'].strip(),
+        filter_kv['matching'].strip(),
+        filter_kv['pass'].strip() if 'pass' in filter_kv else False,
+        filter_kv['memcg_path'].strip(),
+        _damon.DamonRegion(filter_kv['addr_start'].strip(),
+                           filter_kv['addr_end'].strip())
+        if 'addr_start' in filter_kv and 'addr_end' in filter_kv
+        else None,
+        filter_kv['damon_target_idx']
+        if 'damon_target_idx' in filter_kv else None)
             for filter_kv in numbered_dirs_content(
                 files_content, 'nr_filters')]
 
@@ -851,6 +860,10 @@ def update_supported_features():
                          'stats', 'sz_ops_filter_passed')):
         feature_supports['sz_ops_filter_passed'] = True
 
+    if os.path.isfile(
+            os.path.join(scheme_dir_of(0, 0, 0), 'filters', '0', 'pass')):
+        feature_supports['pass_filter'] = True
+
     avail_ops, err = _avail_ops()
     if err == None:
         for ops in ['vaddr', 'paddr', 'fvaddr']:
