@@ -16,6 +16,10 @@ def main(args):
 
         err = _damon.set_damon_interface(damon_interface)
         if err is not None:
+            if damon_interface == 'debugfs':
+                # DAMON debugfs removed kernel?
+                if err == 'DAMON interface (debugfs) not supported':
+                    continue
             print('DAMON interface set with %s failed: %s' %
                   (damon_interface, err))
             exit(1)
@@ -26,8 +30,14 @@ def main(args):
             exit(1)
         report[damon_interface]['feature_supports'] = feature_supports
 
+        kdamonds, err = _damon.update_read_kdamonds(
+                nr_retries=6, update_stats=True, update_tried_regions=True,
+                update_quota_effective_bytes=True)
+        if err != None:
+            print('cannot update and read kdamonds: %s' % err)
+            continue
         report[damon_interface]['kdamonds'] = [
-                k.to_kvpairs() for k in _damon.current_kdamonds()]
+                k.to_kvpairs() for k in kdamonds]
 
     report['damon_reclaim_status'] = damo_reclaim.darc_status()
 
